@@ -1,5 +1,15 @@
 base.bal.tab <- function(X, ...) {
-    UseMethod("base.bal.tab")
+    fun <- switch(attr(X, "X.class"),
+                  "binary" = base.bal.tab.binary,
+                  "cont" = base.bal.tab.cont,
+                  "subclass.binary" = base.bal.tab.subclass.binary,
+                  "subclass.cont" = base.bal.tab.subclass.cont,
+                  "cluster" = base.bal.tab.cluster,
+                  "msm" = base.bal.tab.msm,
+                  "multi" = base.bal.tab.multi,
+                  "imp" = base.bal.tab.imp)
+    
+    fun(X, ...)
 }
 
 base.bal.tab.binary <- function(X, ...) {
@@ -47,8 +57,10 @@ base.bal.tab.base <- function(X,
         no.adj <- FALSE
         if (type == "bin") check_if_zero_weights(X$weights, X$treat)
         else if (type == "cont") check_if_zero_weights(X$weights)
+        
         if (ncol(X$weights) == 1) names(X$weights) <- "Adj"
     }
+    
     if (is_null(X$s.weights)) {
         X$s.weights <- rep(1, length(X$treat))
     }
@@ -105,6 +117,7 @@ base.bal.tab.base <- function(X,
                                        treat_names = treat_names(X$treat),
                                        type = type,
                                        co.names = co.names)
+    
     class(out) <- c(paste.("bal.tab", type), "bal.tab")
     
     out
